summaryrefslogtreecommitdiffstats
path: root/keystone/common
diff options
context:
space:
mode:
authorJenkins <jenkins@review.openstack.org>2013-06-14 16:15:16 +0000
committerGerrit Code Review <review@openstack.org>2013-06-14 16:15:16 +0000
commit9b08fee9dce4e9c4e9628f0c86ef4c94b1b3f910 (patch)
tree399b6926c5eaf3c89d99a681d364fc690389fb13 /keystone/common
parent0e4976f79e8964b42161c13c870908b2e4e90ac5 (diff)
parentce0baf07c0484d7e65b1d93cdd1ec4a1f8fcd60a (diff)
Merge "Allow request headers access in app context."
Diffstat (limited to 'keystone/common')
-rw-r--r--keystone/common/wsgi.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/keystone/common/wsgi.py b/keystone/common/wsgi.py
index a07ae117..d5368b2a 100644
--- a/keystone/common/wsgi.py
+++ b/keystone/common/wsgi.py
@@ -161,9 +161,10 @@ class Application(BaseApplication):
del arg_dict['controller']
LOG.debug(_('arg_dict: %s'), arg_dict)
# allow middleware up the stack to provide context & params
context = req.environ.get(CONTEXT_ENV, {})
context['query_string'] = dict(req.params.iteritems())
+ context['headers'] = dict(req.headers.iteritems())
context['path'] = req.environ['PATH_INFO']
params = req.environ.get(PARAMS_ENV, {})
if 'REMOTE_USER' in req.environ:
@@ -161,9 +161,10 @@ class Application(BaseApplication):
del arg_dict['controller']
LOG.debug(_('arg_dict: %s'), arg_dict)
- # allow middleware up the stack to provide context & params
+ # allow middleware up the stack to provide context, params and headers.
context = req.environ.get(CONTEXT_ENV, {})
context['query_string'] = dict(req.params.iteritems())